#
# 	Program generates a vplot file that draws the grid of F-D 
#	traveltime calculation
#
#	Vfdtime1 par=parfile out=file.v > file.V
#
# FILES
#	INPUT:
#				no
#	OUTPUT:
#		stdout:		a vplot file that draws a figure
#
# PARAMETERS
#	FROM PAR:
#		outtype		=0 for ttm; =1 for amp
#		npoint		length of array
#		xll,yll,xur,yur the true coordinates of the vplot
#
#%end of self doc		

# PARAMETERS FOR ALLOCATING ARRAYS
# define parameters
integer npoint

from par:		integer npoint=16

allocate:	real xx(npoint),yy(npoint)

subroutine submain(npoint,xx,yy)

integer npoint,ipoint,outtype,titlesz,titlefat
integer output,outfd
real xll, yll, xur, yur
real xmin,ymin,xmax,ymax
real x,y,x0,y0,theta
real xrange,yrange,xcenter,ycenter,xyrange
character*50 out
character*50 title,longstg
real xx(npoint),yy(npoint)

# PARAMETERS
	from par:		integer outtype=0,titlesz=12, titlefat=5
	from par:		real xll=1.705,yll=2.56,xur=11.945,yur=7.68
	from par:		character title=" "

#   OUTPUT
	to history:		real xll,yll,xur,yur

# FILES

#   INPUT
#	no input

#   OUTPUT
	outfd = output()
	if(getch('out','s',out) == 0)
	   call vpfilep(outfd)
	else
	   call vpfile(out)

	call vperase()
	call hclose()

# STARTING PROGRAM

	write(0,*) xll,yll,xur,yur
	xmin = 1.
	ymin = 1.
	xmax = 5.
	ymax = 3.
	xcenter=0.5*(xmin+xmax)
	ycenter=0.5*(ymin+ymax)
	xrange = xmax-xmin
	yrange = ymax-ymin
	xyrange = sqrt(xrange*xrange+yrange*yrange)

	call vporig(xll,yll)
	call vpuorig(xmin,ymin)
        x = (xur-xll)/(xmax-xmin)
        y = (yur-yll)/(ymax-ymin)
	call vpscale(x,y)
	
	call vpcolor(7)
	call vpfat(1)
	call vpumove(xmin,ymin)
	call vpudraw(xmin,ymax)
	call vpudraw(xmax,ymax)
	call vpudraw(xmax,ymin)
	call vpudraw(xmin,ymin)
	call vpumove(xcenter,ymin)
	call vpudraw(xcenter,ymax)
	
	call vpcolor(7)
	call vpfat(1)
	x = xmax+0.05*xrange
	y = ymax
	call vpumove(x,y)
	x = xmax+0.15*xrange
	y = ymax
	call vpudraw(x,y)
	x = xmax+0.05*xrange
	y = ymin
	call vpumove(x,y)
	x = xmax+0.15*xrange
	y = ymin
	call vpudraw(x,y)
	x0 = xmax+0.1*xrange
	y0 = ycenter+0.25*yrange
	x = xmax+0.1*xrange
	y = ymax-0.02*yrange
	call vpuarrow(x0,y0,x,y,0.1)
	x0 = xmax+0.1*xrange
	y0 = ycenter-0.25*yrange
	x = xmax+0.1*xrange
	y = ymin+0.02*yrange
	call vpuarrow(x0,y0,x,y,0.1)

	x0 = xmin+0.125*xrange
	y0 = ymin+0.1*yrange
	x = xmin+0.02*xrange
	y = ymin+0.1*yrange
	call vpuarrow(x0,y0,x,y,0.1)
	x0 = xmin+0.375*xrange
	y0 = ymin+0.1*yrange
	x = xcenter-0.02*xrange
	y = ymin+0.1*yrange
	call vpuarrow(x0,y0,x,y,0.1)
	x0 = xmin+0.625*xrange
	y0 = ymin+0.1*yrange
	x = xcenter+0.02*xrange
	y = ymin+0.1*yrange
	call vpuarrow(x0,y0,x,y,0.1)
	x0 = xmax-0.125*xrange
	y0 = ymin+0.1*yrange
	x = xmax-0.02*xrange
	y = ymin+0.1*yrange
	call vpuarrow(x0,y0,x,y,0.1)
	
	do ipoint = 1,npoint
	{
	   theta = (ipoint-1)*8*atan(1.)/(npoint-1)
	   xx(ipoint) = xmin+0.016*xyrange*sin(theta)
	   yy(ipoint) = ymax+0.016*xyrange*cos(theta)
	}
        call vpcolor(5)
        call vpufill(xx,yy,npoint)
        call vpcolor(7)
        call vpfat(4)
        call vpupline(xx,yy,npoint)
	
	do ipoint = 1,npoint
	{
	   theta = (ipoint-1)*8*atan(1.)/(npoint-1)
	   xx(ipoint) = xcenter+0.016*xyrange*sin(theta)
	   yy(ipoint) = ymax+0.016*xyrange*cos(theta)
	}
        call vpcolor(5)
        call vpufill(xx,yy,npoint)
        call vpcolor(7)
        call vpfat(4)
        call vpupline(xx,yy,npoint)
	
	do ipoint = 1,npoint
	{
	   theta = (ipoint-1)*8*atan(1.)/(npoint-1)
	   xx(ipoint) = xmax+0.016*xyrange*sin(theta)
	   yy(ipoint) = ymax+0.016*xyrange*cos(theta)
	}
        call vpcolor(5)
        call vpufill(xx,yy,npoint)
        call vpcolor(7)
        call vpfat(4)
        call vpupline(xx,yy,npoint)
	
	do ipoint = 1,npoint
	{
	   theta = (ipoint-1)*8*atan(1.)/(npoint-1)
	   xx(ipoint) = xcenter+0.016*xyrange*sin(theta)
	   yy(ipoint) = ymin+0.016*xyrange*cos(theta)
	}
        call vpcolor(0)
        call vpufill(xx,yy,npoint)
        call vpcolor(2)
        call vpfat(4)
        call vpupline(xx,yy,npoint)
  
	call vpcolor(7)
	call vpfat(2)
	call vptjust(2,3)
	x = xmax+0.1*xrange
	y = ycenter
	call vputext(x,y,8,0,'\\F10 D\\F3 r')
	x = xmin+0.25*xrange
	y = ymin+0.1*yrange
	call vputext(x,y,8,0,'r\\F10 Dq')
	x = xmax-0.25*xrange
	y = ymin+0.1*yrange
	call vputext(x,y,8,0,'r\\F10 Dq')
	x = xmin
	y = ymax+0.15*yrange
	if(outtype == 0)
	   call vputext(x,y,8,0,'\\F10 t\\s60 \\F3 \\_i-1,j\\^')
	else
	   call vputext(x,y,8,0,'\\F10 g\\s60 \\F3 \\_i-1,j\\^')
	x = xcenter
	y = ymax+0.15*yrange
	if(outtype == 0)
	   call vputext(x,y,8,0,'\\F10 t\\s60 \\F3 \\_i,j\\^')
	else
	   call vputext(x,y,8,0,'\\F10 g\\s60 \\F3 \\_i,j\\^')
	x = xmax
	y = ymax+0.15*yrange
	if(outtype == 0)
	   call vputext(x,y,8,0,'\\F10 t\\s60 \\F3 \\_i+1,j\\^')
	else
	   call vputext(x,y,8,0,'\\F10 g\\s60 \\F3 \\_i+1,j\\^')
	x = xcenter
	y = ymin-0.1*yrange
	if(outtype == 0)
	   call vputext(x,y,8,0,'\\F10 t\\s60 \\F3 \\_i,j+1\\^')
	else
	   call vputext(x,y,8,0,'\\F10 g\\s60 \\F3 \\_i,j+1\\^')
	call vptfont(-1,-1,2)
	x = xmin+0.25*xrange
	y = ymax
	if(outtype == 0)
	   call vputext(x,y,8,0,'u\\s60 \\_i-1,j\\^')
	else
	   call vputext(x,y,8,0,'f\\s60 \\_i-1,j\\^')
	x = xmin+0.75*xrange
	y = ymax
	if(outtype == 0)
	   call vputext(x,y,8,0,'u\\s60 \\_i,j\\^')
	else
	   call vputext(x,y,8,0,'f\\s60 \\_i,j\\^')
	x = xcenter
	y = ycenter
	if(outtype == 0)
	{
	   longstg = "w\\h\\>\\>\\>\\^\\F15 H\\s60 \\_ \\F3 \\_i,j\\^"
	   call vputext(x,y,8,0,longstg)
	}
	else
	{
	   longstg = "g\\h\\>\\>\\>\\^\\F15 H\\s60 \\_ \\F3 \\_i,j\\^"
	   call vputext(x,y,8,0,longstg)
	}
	x = xmin+0.25*xrange
	y = ycenter
	call vputext(x,y,8,0,'v\\s60 \\_i-1,j\\^')
	x = xmin+0.75*xrange
	y = ycenter
	call vputext(x,y,8,0,'v\\s60 \\_i,j\\^')

# write title
	call vptfont(-1,-1,2)
	call vpcolor(7)
	call vpfat(titlefat)
        call vptjust(2,1)
        x = xcenter
        y = ymax+0.1*xyrange
        call vputext(x,y,titlesz,0,title)
	
stop 
end

