#	Generate a vplot file that draws triangle grid
#
#	vptrigrid.x par=trigrid.p out=trigrid.v 
#
# FILES:
#	INPUT:	
#	OUTPUT:
#		stdout:	vplot file
#		
# PARAMETERS:
#	FROM INPUT:
#	FROM PAR:
#		xll,yll,xur,yur the true coordinates of the vplot
#		plotcol=6 	color of plot
#		plotfat=1	fat of plot
#		wantframe=0	=0 no frame; =1 frame
#		detail=1	=0 no detail; =1 show detail
#				
#
# NOTE:
#% end of self doc
#
#-------------
# keyword: dmo geometry
#-------------

integer narray

from par:	integer narray=11

allocate:	real xx(narray),zz(narray)

subroutine submain(narray,xx,zz)

integer nz,nx,nth,nr,nrconst,iz,ix,ith,ir
integer narray,iarray
integer plotcol,plotfat,titlesz,titlefat,fat
integer wantframe,detail
integer outfd, output
real z0,x0,dz,dx
real xll,yll,xur,yur
real xmin,zmin,xmax,zmax,xrange,zrange,zxrange
real xcenter,zcenter,xscale,zscale
real x,z,x1,z1,x2,z2
real theta0,dtheta,th0,dth,r0,dr,rmax
real theta,y,h0,dh,th,r,xs,zs
real xx(narray),zz(narray)
character*50 out
character*50 title

# PARAMETERS
#    INPUT 
	from par:	integer n1:nz=10,n2:nx=20
	from par:	integer nrconst=4
	from par:	integer plotcol=6,plotfat=1,titlesz=12,titlefat=5
	from par:	integer wantframe=0,detail=1
	from par:	real xll=1.705,yll=2.56,xur=11.945,yur=7.68
	from par:	real o1:z0=0.,o2:x0=0.,d1:dz=0.01,d2:dx=0.01
	from par:	real theta=45.,y=0.5,h0=0.,dh=0.1
	from par:	character title=" "

#    OUTPUT

# CHECK

# FILES
#   INPUT

#   OUTPUT
	outfd = output()
	if(getch('out','s',out) == 0)
	   call vpfilep(outfd)
	else
	   call vpfile(out)

	call hclose()

# CALCULATION 
	#set parameters
	xmin = x0
	zmin = z0
	xmax = x0+(nx-1)*dx
	zmax = z0+(nz-1)*dz
	xcenter=0.5*(xmin+xmax)
	zcenter=0.5*(zmin+zmax)
	xrange = xmax-xmin
	zrange = zmax-zmin
	zxrange = sqrt(xrange*xrange+zrange*zrange)
	xs = xcenter
	zs = zmin
	nth = nx
	nr = nz
	th0 = -2.*atan(1.)
	dth = -2.*th0/(nth-1)
	r0 = 0.
	rmax = min(zmax-zmin,0.5*(xmax-xmin))
	dr = rmax/(nr-1)
		
	# set vplot scales
	call vporig(xll,yur)
	call vpuorig(xmin,zmin)
        xscale = (xur-xll)/(xmax-xmin)
        zscale = -(yur-yll)/(zmax-zmin)
	call vpscale(xscale,zscale)
	write(0,*) 'xscale,zscale', xscale,zscale

# draw a polar grid
	call vpcolor(7)
	call vpfat(plotfat)
	do ith = 1,nth
	{
	   th = th0+(ith-1)*dth
	   x = xs
	   z = zs
	   call vpumove(x,z)
	   x = xs+rmax*sin(th)
	   z = zs+rmax*cos(th)
	   call vpudraw(x,z)
	}
	do ir = 2,nr
	{
	   r = r0+(ir-1)*dr
	   x = xs+r*sin(th0)
	   z = zs+r*cos(th0)
	   call vpumove(x,z)
	   do ith = 2,5*nth
	   {
	      th = th0+(ith-1)*(-2.*th0)/(5*nth-1)
	      x = xs+r*sin(th)
	      z = zs+r*cos(th)
	      call vpudraw(x,z)
	   }
	}
	
        call vpcolor(7)
        fat = 8*plotfat
        call vpfat(fat)
	x = xmin
	z = zmin
	call vpumove(x,z)
	x = xmax
	z = zmin
	call vpudraw(x,z)

# draw source point
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = xs+0.014*zxrange*sin(theta)
	   zz(iarray) = zs+0.014*zxrange*cos(theta)
	}
	call vpcolor(2)
	call vpufill(xx,zz,narray)
	call vpcolor(7)
	fat = 4*plotfat
	call vpfat(fat)
	call vpupline(xx,zz,narray)
	
# draw grid points
	do ir = nrconst,nr
	{
	   r = r0+(ir-1)*dr
	   do ith = 1,nth
	   {
	      th = th0+(ith-1)*dth
	      x = xs+r*sin(th)
	      z = zs+r*cos(th)
	      do iarray = 1,narray
	      {
	         theta = (iarray-1)*8*atan(1.)/(narray-1)
	         xx(iarray) = x+0.008*zxrange*sin(theta)
	         zz(iarray) = z+0.008*zxrange*cos(theta)
	      }
	      if(ir <= (nr+nrconst)/2)
	         call vpcolor(5)
	      else
	         call vpcolor(0)
	      call vpufill(xx,zz,narray)
	      call vpcolor(7)
	      fat = 4*plotfat
	      call vpfat(fat)
	      call vpupline(xx,zz,narray)
	   }
	}
	ir = (nr+nrconst)/2+1
	r = r0+(ir-1)*dr
	do ith = 1,nth
	{
	   th = th0+(ith-1)*dth
	   x = xs+r*sin(th)
	   z = zs+r*cos(th)
	   do iarray = 1,5
	   {
	      xx(1) = x-0.008*zxrange
	      zz(1) = z-0.008*zxrange
	      xx(2) = x-0.008*zxrange
	      zz(2) = z+0.008*zxrange
	      xx(3) = x+0.008*zxrange
	      zz(3) = z+0.008*zxrange
	      xx(4) = x+0.008*zxrange
	      zz(4) = z-0.008*zxrange
	      xx(5) = x-0.008*zxrange
	      zz(5) = z-0.008*zxrange
	   }
	   call vpcolor(0)
	   call vpufill(xx,zz,5)
	   call vpcolor(6)
	   fat = 4*plotfat
	   call vpfat(fat)
	   call vpupline(xx,zz,5)
	}

# write title
	call vpcolor(7)
	call vpfat(titlefat)
        call vptjust(2,1)
        x = xcenter
        z = zmin-0.008*titlesz*zxrange
        call vputext(x,z,titlesz,0,title)

	call vpcolor(7)
	fat = 4*plotfat
	call vpfat(fat)
        call vptjust(2,1)
	x = xs+(nrconst-1)*dr
	z = zs-0.4*dz
	call vputext(x,z,8,0,'r\\s60 \\_0\\^')
	x = xs+((nr+nrconst)/2-1)*dr
	z = zs-0.4*dz
	call vputext(x,z,8,0,'r\\s60 \\_j\\^')
	x = xs+((nr+nrconst)/2)*dr
	z = zs-0.4*dz
	call vputext(x,z,8,0,'r\\s60 \\_j+1\\^')

# draw a frame
	if(wantframe != 0.)
	{
	   call vpcolor(7)
	   call vpfat(1)
	   call vpumove(xmin,zmin)
	   call vpudraw(xmin,zmax)
	   call vpudraw(xmax,zmax)
	   call vpudraw(xmax,zmin)
	   call vpudraw(xmin,zmin)
	}
	   
stop
end
